@@ -25,13 +25,11 @@
 
 `convert` <- function(from, to = NULL, embed = FALSE, ...) {
     if (missing(from)) {
-        cat("\n")
-        stop("Argument 'from' is missing.\n\n", call. = FALSE)
+        admisc::stopError("Argument 'from' is missing.")
     }
     
     # if (missing(to)) {
-    #     cat("\n")
-    #     stop(sprintf("Argument %s is missing.\n\n", dQuote("to")), call. = FALSE)
+    #     admisc::stopError("sprintf("Argument %s is missing.", dQuote("to").")
     # }
 
     dots <- list(...)
@@ -52,36 +50,58 @@
     }
     else if (is.element("data.frame", class(from))) {
         Robject <- TRUE
-        tp_from <- list(completePath = ".", filenames = as.character(substitute(from)), fileext = "RDS")
+        tp_from <- list(
+            completePath = ".",
+            filenames = as.character(substitute(from)),
+            fileext = "RDS"
+        )
     }
     else {
-        cat("\n")
-        stop("Unsuitable input.\n\n", call. = FALSE)
+        admisc::stopError("Unsuitable input.")
     }
 
     if (!is.null(to)) {
         
         if (identical(toupper(to), "EXCEL")) {
-            to <- file.path(tp_from$completePath, paste(tp_from$filenames, "xlsx", sep = "."))
+            to <- file.path(
+                tp_from$completePath,
+                paste(tp_from$filenames, "xlsx", sep = ".")
+            )
         }
         else if (identical(toupper(to), "DDI") | identical(toupper(to), "XML")) {
-            to <- file.path(tp_from$completePath, paste(tp_from$filenames, "xml", sep = "."))
+            to <- file.path(
+                tp_from$completePath,
+                paste(tp_from$filenames, "xml", sep = ".")
+            )
         }
         else if (identical(toupper(to), "SPSS")) {
-            to <- file.path(tp_from$completePath, paste(tp_from$filenames, "sav", sep = "."))
+            to <- file.path(
+                tp_from$completePath,
+                paste(tp_from$filenames, "sav", sep = ".")
+            )
         }
         else if (identical(toupper(to), "STATA")) {
-            to <- file.path(tp_from$completePath, paste(tp_from$filenames, "dta", sep = "."))
+            to <- file.path(
+                tp_from$completePath,
+                paste(tp_from$filenames, "dta", sep = ".")
+            )
         }
         else if (identical(toupper(to), "R")) {
-            to <- file.path(tp_from$completePath, paste(tp_from$filenames, "rds", sep = "."))
+            to <- file.path(
+                tp_from$completePath,
+                paste(tp_from$filenames, "rds", sep = ".")
+            )
         }
         else if (identical(toupper(to), "SAS")) {
-            to <- file.path(tp_from$completePath, paste(tp_from$filenames, "sas7bdat", sep = "."))
+            to <- file.path(
+                tp_from$completePath,
+                paste(tp_from$filenames, "sas7bdat", sep = ".")
+            )
         }
         else if (!grepl("[.]", to)) {
-            cat("\n")
-            stop("Unknown destination software.\n\n", call. = FALSE)
+            admisc::stopError(
+                "Unknown destination software."
+            )
         }
 
         tp_to <- treatPath(to, single = TRUE, check = FALSE)
@@ -93,44 +113,69 @@
         known_extensions <- c("RDS", "SAV", "DTA", "XML", "SAS7BDAT", "XLSX") # 
 
         if (is.na(tp_to$fileext)) {
-            cat("\n")
-            stop("Cannot determine the destination software without a file extension.\n\n", call. = FALSE)
+            admisc::stopError(
+                "Cannot determine the destination software without a file extension."
+            )
         }
         else if (!is.element(tp_to$fileext, known_extensions)) {
-            cat("\n")
-            stop("Unknown destination software %s.\n\n", call. = FALSE)
+            admisc::stopError("Unknown destination software.")
         }
     }
 
     if (tp_from$fileext == "XML") {
-        codeBook <- getMetadata(from, spss = ifelse(is.null(to), FALSE, identical(tp_to$fileext, "SAV")))
-        
-        if (is.element("datafile", names(codeBook[["fileDscr"]]))) {
+        codeBook <- getMetadata(
+            from,
+            spss = ifelse(
+                is.null(to),
+                FALSE,
+                identical(tp_to$fileext, "SAV")
+            )
+        )
+
+        if (is.element(
+            "datafile",
+            names(codeBook[["fileDscr"]])
+        )) {
             data <- codeBook[["fileDscr"]][["datafile"]]
         }
         else {
             files <- getFiles(tp_from$completePath, "*")
-            
+
             csvexists <- FALSE
             csvfiles <- files$fileext == "CSV"
             if (any(csvfiles)) {
-                csvexists <- is.element(toupper(tp_from$filenames), toupper(files$filenames[csvfiles]))
-                csvfile <- files$files[csvfiles][match(toupper(tp_from$filenames), toupper(files$filenames[csvfiles]))]
+                csvexists <- is.element(
+                    toupper(tp_from$filenames),
+                    toupper(files$filenames[csvfiles])
+                )
+                csvfile <- files$files[csvfiles][
+                    match(
+                        toupper(tp_from$filenames),
+                        toupper(files$filenames[csvfiles])
+                    )
+                ]
             }
-            
+
             if (!csvexists) {
-                cat("\n")
-                stop("Datafile not found.\n\n", call. = FALSE)
+                admisc::stopError("Datafile not found.")
             }
 
             # data <- suppressMessages(readr::read_csv(file.path(tp_from$completePath, csvfile)))
-            data <- read.csv(file.path(tp_from$completePath, csvfile), as.is = TRUE)
+            data <- read.csv(
+                file.path(tp_from$completePath, csvfile),
+                as.is = TRUE
+            )
+
             if (ncol(data) == length(codeBook$dataDscr) + 1) {
                 rownames(data) <- data[, 1]
                 data <- data[, -1, drop = FALSE]
             }
             # return(list(data = data, codeBook = codeBook))
-            data <- make_labelled(data, codeBook$dataDscr, spss = identical(tp_to$fileext, "SAV"))
+            data <- make_labelled(
+                data,
+                codeBook$dataDscr,
+                spss = identical(tp_to$fileext, "SAV")
+            )
         }
     }
     else {
@@ -142,8 +187,14 @@
                         callist[[f]] <- dots[[f]]
                     }
                 }
-                
-                data <- do.call(paste("read", tolower(tp_from$fileext), sep = "_"), callist)
+
+                data <- do.call(
+                    paste(
+                        "read",
+                        tolower(tp_from$fileext),
+                        sep = "_"
+                    ),
+                callist)
             # }
         }
         else if (tp_from$fileext == "SAV") {
@@ -154,7 +205,13 @@
         }
         else if (tp_from$fileext == "DTA") {
             data <- haven::read_dta(from)
-            data <- recodeMissing(data, to = "SPSS", dictionary = dictionary, to_declared = FALSE, error_null = FALSE)
+            data <- recodeMissing(
+                data,
+                to = "SPSS",
+                dictionary = dictionary,
+                to_declared = FALSE,
+                error_null = FALSE
+            )
         }
         else if (tp_from$fileext == "SAS7BDAT") {
             data <- haven::read_sas(from)
@@ -175,13 +232,22 @@
     if (!is.null(to)) {
         if (tp_to$fileext == "XML") {
             if (is.null(codeBook)) {
-                cat("\n")
-                stop("The input does not seem to contain any metadata.\n\n", call. = FALSE)
+                admisc::stopError(
+                    "The input does not seem to contain any metadata."
+                )
             }
             codeBook$fileDscr$datafile <- data
-            
+
             if (!embed) {
-                file <- file.path(tp_from$completePath, paste(tp_to$filenames[1], "csv", sep = "."))
+                file <- file.path(
+                    tp_from$completePath,
+                    paste(
+                        tp_to$filenames[1],
+                        "csv",
+                        sep = "."
+                    )
+                )
+
                 write.csv(
                     x = data,
                     file = as.character(file),
@@ -201,28 +267,40 @@
                 return(x)
             })
             
-            haven::write_sav(data, to)
+            haven::write_sav(declared::as_haven(data), to)
         }
         else if (identical(tp_to$fileext, "DTA")) {
             colnms <- colnames(data)
             if (!is.null(codeBook)) {
                 for (i in seq(ncol(data))) {
-                    if (!is.null(values <- codeBook$dataDscr[[colnms[i]]]$values)) {
+                    values <- codeBook$dataDscr[[colnms[i]]]$values
+                    if (!is.null(values)) {
                         if (admisc::possibleNumeric(values)) {
                             if (!admisc::wholeNumeric(admisc::asNumeric(values))) {
-                                cat("\n")
-                                stop(sprintf("Stata does not allow labels for non-integer variables (e.g. \"%s\").\n\n", colnms[i]), call. = FALSE)
+                                admisc::stopError(
+                                    sprintf(
+                                        "Stata does not allow labels for non-integer variables (e.g. \"%s\").",
+                                        colnms[i]
+                                    )
+                                )
                             }
                         }
                     }
                 }
-                
-                callist <- list(data = recodeMissing(data, to = "Stata", dictionary = dictionary, error_null = FALSE))
+
+                callist <- list(
+                    data = recodeMissing(
+                        data,
+                        to = "Stata",
+                        dictionary = dictionary,
+                        error_null = FALSE
+                    )
+                )
             }
             else {
                 callist <- list(data = data)
             }
-            
+
             if (is.element("version", names(dots))) {
                 callist$version <- dots$version
             }
@@ -260,6 +338,10 @@
         }
 
     }
-    
-    return(invisible(as.data.frame(declared::as_declared(data))))
+
+    return(
+        invisible(
+            as.data.frame(declared::as_declared(data))
+        )
+    )
 }
